@@ -123,6 +123,15 @@ class SavableData:
             return None
 
 
+@dataclass
+class MassRange(SavableData):
+    """Mass range to be allowed."""
+
+    mass_range: np.ndarray
+
+    group_name: ClassVar[str] = "mass_range"
+
+
 @dataclass
 class DownsamplingIndices(SavableData):
     """Indices to be used to select a subset of frequencies
